@@ -253,6 +253,16 @@ DayBeforeDecorationAdhoc = [
     Timestamp('1961-05-29', tz='UTC')
 ]
 
+#######################################
+# US Juneteenth (June 19th)
+#######################################
+USJuneteenthAfter2022 = Holiday(
+    'Juneteenth Starting at 2022',
+    start_date=Timestamp('2022-06-19'),
+    month=6, day=19,
+    observance=nearest_workday,
+)
+
 #######################################
 # US Independence Day July 4
 #######################################
@@ -1460,4 +1470,5 @@ HurricaneSandyClosings2012 = [Timestamp('2012-10-29', tz='UTC'),
                               Timestamp('2012-10-30', tz='UTC')]
 
 # 2018
-GeorgeHWBushDeath2018 = [Timestamp('2018-12-05', tz='UTC'),]
\ No newline at end of file
+GeorgeHWBushDeath2018 = [Timestamp('2018-12-05', tz='UTC'),]
+
